%define _with_repolib 1

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'
%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define version_maj  1
%define version_min  2
%define version_rev  13 
%define version_tag -patch-01
%define namedversion %{version_maj}.%{version_min}_%{version_rev}
%define version_full %{version_maj}.%{version_min}_%{version_rev}%{version_tag}

#- is not allowed in the Release: tag, so changing to _
%define brewreltag _patch_01

Summary:        GlassFish JSF
Name:           glassfish-jsf
Version:        %{namedversion}
Release:        5%{brewreltag}.3%{?dist}
Epoch:          0
License:        CDDL
Group:          Development/Java
URL:            https://javaserverfaces.dev.java.net/

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildArch:      noarch

Source0:        %{name}-%{version}.zip
# https://javaserverfaces.dev.java.net/files/documents/1866/115489/mojarra-1.2_10-b01-FCS-source.zip

Source1:        %{name}-%{version}-deps.tar.gz
# FIXME: Get rid of these prebuilt binaries
# http://download.java.net/javaee5/external/shared/com-sun-commons-beanutils/jars/com-sun-commons-beanutils-1.6.1.jar
# http://download.java.net/javaee5/external/shared/com-sun-commons-collections/jars/com-sun-commons-collections-2.1.jar
# http://download.java.net/javaee5/external/shared/com-sun-commons-digester/jars/com-sun-commons-digester-1.5.jar
# http://download.java.net/javaee5/external/shared/com-sun-commons-logging/jars/com-sun-commons-logging-1.0.4.jar
# http://repository.codehaus.org/org/codehaus/groovy/groovy-all/1.5.5/groovy-all-1.5.5.jar

Source2:        %{name}-build.xml
Source3:        %{name}-%{version}-impl-overlay.jar
# This is derived from the contents of this zip:
# https://javaserverfaces.dev.java.net/files/documents/1866/115488/mojarra-1.2_10-b01-FCS-binary.zip
# The files in the jar are those selected by the following command:
# find -type f '!' -iname *.class '!' -wholename '*com/sun/org/apache*'
# This is necessary to replicate Sun's binary distribution as closely as possible
# and is applied in the build.xml

Source4:        %{name}-component-info.xml
#https://svn.jboss.org/repos/repository.jboss.org/maven2-brew/javax/faces/jsf-api/1.2_13/jsf-api-1.2_13.pom
Source5:	jsf-api-1.2_13.pom
#https://svn.jboss.org/repos/repository.jboss.org/maven2-brew/javax/faces/jsf-impl/1.2_13/jsf-impl-1.2_13.pom
Source6:	jsf-impl-1.2_13.pom
# JBPAPP-6414 Packaging Xerces in war causes JSF ClassCastException on SAXParserFactory
Patch0:         %{name}-JBPAPP-6414-4.patch

BuildRequires:  ant
BuildRequires:  servletapi6
BuildRequires:  glassfish-jstl
BuildRequires:	java >= 1.5.0
BuildRequires:  jbossweb
BuildRequires:  apache-portlet-1.0-api
BuildRequires:  jpackage-utils
BuildRequires: 	groovy15 
#JDK5 don't have javax.annotation
#BuildRequires:  geronimo-annotation-1.0-api
#BuildRequires:  geronimo-el-1.0-api
%description
The JSF 1.2 implementation. NB: We've omitted the classes
Jetty6InjectionProvider and GlassFishInjectionProvider from the
package com.sun.faces.vendor.


%define repodir %{_javadir}/repository.jboss.com/glassfish/jsf/%{version_full}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %{with_repolib}
%package	 repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	Development/Libraries/Java

%description	 repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio
%endif


%prep

# Unroll the sources into a clean heirarchy for our ant buildfile
mkdir -p together/{api,impl,tools,deps}/{src,build}

unzip %{SOURCE0}
cp -R mojarra-%{version}-b01-FCS-sources/jsf-api/src/* \
      mojarra-%{version}-b01-FCS-sources/jsf-api/build/generate/* together/api/src
cp -R mojarra-%{version}-b01-FCS-sources/jsf-ri/src/* \
      mojarra-%{version}-b01-FCS-sources/jsf-ri/build/generate/* together/impl/src
cp -R mojarra-%{version}-b01-FCS-sources/jsf-tools/src/* together/tools/src

pushd together/impl
%patch0 -p2 -b .sav0
popd

# FIXME: Get rid of these prebuilt binaries
pushd together/deps
  tar -xzvf %{SOURCE1}
  jar xvf com-sun-commons-logging-1.0.4.jar
  rm -f com-sun-commons-logging-1.0.4.jar
  jar xvf com-sun-commons-beanutils-1.6.1.jar
  rm -f com-sun-commons-beanutils-1.6.1.jar
  jar xvf com-sun-commons-digester-1.5.jar
  rm -f com-sun-commons-digester-1.5.jar
  jar xvf com-sun-commons-collections-2.1.jar
  rm -f com-sun-commons-collections-2.1.jar
  # add groovy-all.jar to classpath
  ln -s /usr/share/java/groovy15-all.jar groovy-all.jar
  # add javax.annotation jar
#  ln -s /usr/share/java/geronimo-annotation-1.0-api.jar geronimo-annotation-api.jar
  ln -s /usr/share/java/jbossas/jboss-ejb3x.jar jboss-ejb3.jar
  deppath=$(build-classpath-directory $(pwd))
  echo $deppath
popd

pushd together
  cp %{SOURCE2} ./build.xml
  sed -i "s|@DEP-PATH@|$deppath|g;" build.xml
  sed -i "s|@BASE-DIR@|`pwd`|g;" build.xml
  s3=%{SOURCE3}
  sed -i "s|@IMPL-OVERLAY@|$s3|g;" build.xml
  sed -i "s|@MF-SPEC-TITLE@|JavaServer Faces|g;" build.xml
  sed -i "s|@MF-SPEC-VERSION@|1.2MR1|g;" build.xml
  sed -i "s|@MF-IMPL-TITLE@|Sun Microsystems JavaServer Faces Implementation|g;" build.xml
  implversion=%{version_full}-b02-FCS
  sed -i "s|@MF-IMPL-VERSION@|$implversion|g;" build.xml

  # These injection providers are too much trouble to build (and not useful to JBoss)
  rm -f impl/src/com/sun/faces/vendor/{GlassFish,Jetty6}InjectionProvider.java
popd

# component-info:
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{SOURCE4}
sed -i s/@VERSION@/%{version_full}-brew/g %{SOURCE4}


%build
pushd together
  ant jar
popd


%install
rm -rf $RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/
install -p -m 0644 together/api/build/jsf-api.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-api-%{version_full}.jar
install -p -m 0644 together/impl/build/jsf-impl.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-impl-%{version_full}.jar

pushd $RPM_BUILD_ROOT%{_javadir}
    ln -sf %{name}-api-%{version_full}.jar  %{name}-api.jar
    ln -sf %{name}-impl-%{version_full}.jar %{name}-impl.jar
    
    ln -sf %{name}-api-%{version_full}.jar  jsf-api.jar
    ln -sf %{name}-impl-%{version_full}.jar jsf-impl.jar
popd

#poms
mkdir -p $RPM_BUILD_ROOT%{_datadir}/maven2/poms
sed -i s/@VERSION@/%{version_full}/ %{SOURCE5}
cp -p %{SOURCE5} $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-jsf-api.pom
%add_to_maven_depmap javax.faces jsf-api %{version_full} JPP %{name}

sed -i s/@VERSION@/%{version_full}/ %{SOURCE6}
cp -p %{SOURCE6} $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-jsf-impl.pom
%add_to_maven_depmap javax.faces jsf-impl %{version_full} JPP %{name}

%if %{with_repolib}
    install -d -m 755 $RPM_BUILD_ROOT%{repodir}
    install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
    install -m 755 %{SOURCE4} $RPM_BUILD_ROOT%{repodir}/component-info.xml
    install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
    install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
    install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
    install -m 755 %{SOURCE2} $RPM_BUILD_ROOT%{repodirsrc}
    install -m 755 %{SOURCE3} $RPM_BUILD_ROOT%{repodirsrc}
    install -m 755 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
    cp --dereference $RPM_BUILD_ROOT%{_javadir}/jsf-api.jar $RPM_BUILD_ROOT%{repodirlib}
    cp --dereference $RPM_BUILD_ROOT%{_javadir}/jsf-impl.jar $RPM_BUILD_ROOT%{repodirlib}
    cp -p %{SOURCE5} %{buildroot}%{repodirlib}/jsf-api.pom
    cp -p %{SOURCE6} %{buildroot}%{repodirlib}/jsf-impl.pom


%endif


%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(0644,root,root,0755)
%{_javadir}/jsf-api.jar
%{_javadir}/%{name}-api.jar
%{_javadir}/%{name}-api-%{version_full}.jar
%{_javadir}/jsf-impl.jar
%{_javadir}/%{name}-impl.jar
%{_javadir}/%{name}-impl-%{version_full}.jar
%{_datadir}/maven2/poms/*.pom
%{_mavendepmapfragdir}/*

%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{repodir}
%endif


%changelog
* Tue Oct 11 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.2_13-5_patch_01.3
- Update patch for JBPAPP-6414

* Thu Oct 06 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.2_13-5_patch_01.2
- Update patch for JBPAPP-6414

* Wed Sep 28 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.2_13-5_patch_01.1
- Update patch for JBPAPP-6414

* Thu Sep  1 2011 Dustin Kut Moy Cheung <dcheung@redhat.com> - 0:1.2_13-4_patch_01.4
- Added jsf-impl-1.2_13.pom and jsf-api-1.2_13.pom

* Wed Aug 24 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.2_13-4_patch_01.3
- Rebuild to properly apply the patch

* Thu Aug 18 2011 Permaine Cheung <pcheung@redhat.com> - 0:1.2_13-4_patch_01.2
- Rebuild with 1.6.0 OpenJDK

* Tue Aug 09 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.2_13-4_patch_01.1
- Upgrade to 1.2_13-patch-01

* Mon May 17 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.2_13-3.1.1
- rebuilt

* Tue Apr 20 2010 Luiz Barreiros <gbarreir@redhat.com> 0:1.2_13-4
- Rebuild

* Thu Aug 06 2009 Fernando Nasser <fnasser@redhat.com> 0:1.2_13-3
- Replace "BR jbossweb" with "BR tomcat6", drop circular deps
- BR:  geronimo-el-1.0-api
- Update glassfish-jsf-build.xml, use geronimo's el-api && annotation instead
- Add el-api to deppath

* Thu Aug 06 2009 Fernando Nasser <fnasser@redhat.com> 0:1.2_13-2
- Add updated overlay file

* Thu Aug 06 2009 Fernando Nasser <fnasser@redhat.com> 0:1.2_13-1
- Upgrade to 1.2_13
- Remove overlay

* Tue Jun 23 2009 Yong Yang <yyang@redhat.com> 0:1.2_10-0jpp.ep1.6
- BR geronimo-annotation-1.0-api

* Tue Nov 25 2008 Yong Yang <yyang@redhat.com> 0:1.2_10-0jpp.ep1.5
- BR java 1.5

* Fri Nov 21 2008 Yong Yang <yyang@redhat.com> 0:1.2_10-0jpp.ep1.4
- Bump version number

* Fri Nov 21 2008 Yong Yang <yyang@redhat.com> 0:1.2_10-0jpp.ep1.3
- BR groovy15 instead of bundling its jar

* Wed Nov 05 2008 Yong Yang <yyang@redhat.com> 0:1.2_10-0jpp.ep1.2
- updating to 1.2_10

* Thu Jul 24 2008 Jon Prindiville <jprindiv@redhat.com> 0:1.2_09-0jpp.ep1.2
- Fixing version tag

* Thu Jul 24 2008 Jon Prindiville <jprindiv@redhat.com> 0:1.2_09-0jpp.ep1.1
- Updating to 1.2_09

* Mon Jul 21 2008 Jon Prindiville <jprindiv@redhat.com> 0:1.2_08-0jpp.ep1.4
- Moving from sun-jsf to glassfish/jsf (in repolib)

* Thu Apr 24 2008 Jon Prindiville <jprindiv@redhat.com> 0:1.2_08-0jpp.ep1.3
- Output JARs now have proper MANIFEST.MFs

* Wed Mar 19 2008 Jon Prindiville <jprindiv@redhat.com> 0:1.2_08-0jpp.ep1.1
- Upgrading to 1.2_08

* Fri Nov 30 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.18
- Adding a bunch of Apache commons source to compile in with the -impl stuff

* Thu Nov 29 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.17
- Adding an "overlay" JAR containing all of the non-classfiles which our -impl
  JAR is missing when compared to Sun's (see also, note at Source1)
- Adding the overlay jar and -build.xml to %%{repodirsrc}

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.16
- Adding jbossweb's annotations-api.jar to the impl's classpath

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.15
- Fixing mistakely clobbered @API-DIR@ and @IMPL-DIR@ targets in -build.xml

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.14
- First complete build

* Fri Nov 23 2007 Fernando Nasser <fnasser@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.13
- Revert to sun-jaf name to please buildmagic

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.12
- Added -brew suffix.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.11
- %%{release} twiddling (to appease the packaging gods)

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.11.p02
- Fixed build.xml path confusion.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.10.p02
- Brain not work good today. BuildRequiring ant.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.9.p02
- Fixed 'make new-source's omission of the jsf-impl JAR from sources

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.8.p02
- Uploaded new (non-broken!) version of Source0

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.7.p02
- Corrected %%install section, and -impl's %%setup

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.6.p02
- Unbreaking the references to the ant buildfile

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.5.p02
- Using ant rather than inlining the build in the specfile

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.4.p02
- Changed -api's javac invocation

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.3.p02
- Added -api's sources to its classpath

* Thu Nov 22 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.2.p02
- Removed version specification from BR: glassfish-jstl

* Thu Nov 22 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.1.p02
- First release. The -api JAR is building, the -impl JAR is not (yet).
